@@ -23,7 +23,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
