@@ -648,7 +648,7 @@ trigger_on_symbol_inserted (SymbolDBViewLocals *dbvl, gint symbol_id)
 		/*DEBUG_PRINT ("trigger_on_symbol_inserted (): consuming slist for parent %d",
 					 symbol_id);*/
 
-		for (i=0; i < length-1; i++)
+		for (i=0; i < length; i++)
 		{
 			wfs = g_slist_nth_data (slist, 0);
 				
@@ -699,9 +699,8 @@ add_new_waiting_for (SymbolDBViewLocals *dbvl, gint parent_symbol_id,
 	{
 		/* no lists already set. Create one. */
 		GSList *slist;					
-		slist = g_slist_alloc ();			
 				
-		slist = g_slist_prepend (slist, wfs);
+		slist = g_slist_prepend ((GSList *)NULL, wfs);
 					
 		/*DEBUG_PRINT ("add_new_waiting_for (): NEW adding to "
 					 "waiting_for [%d]", parent_symbol_id);*/
@@ -1131,7 +1130,7 @@ on_symbol_removed (SymbolDBEngine *dbe, gint symbol_id, gpointer data)
 	g_return_if_fail (dbvl != NULL);
 	priv = dbvl->priv;
 
-	if (priv->display_nothing)
+	if (priv->display_nothing || (priv->nodes_displayed == NULL))
 	{
 		return;
 	}
@@ -1163,7 +1162,7 @@ on_symbol_scope_updated (SymbolDBEngine *dbe, gint symbol_id, gpointer data)
 	g_return_if_fail (dbvl != NULL);
 	priv = dbvl->priv;
 
-	if (priv->display_nothing)
+	if (priv->display_nothing || (priv->nodes_displayed == NULL))
 	{
 		return;
 	}
